==> django_admin_data_views-0.2.6.tar.gz: django_admin_data_views-0.2.6/README.md <==
# Django Admin Data Views

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Downloads][downloads-badge]][pypi]

[![Python Version][version-badge]][pypi]
[![Django Version][django-badge]][pypi]

```shell
pip install django-admin-data-views
```

---

**Documentation**: [https://mrthearman.github.io/django-admin-data-views/](https://mrthearman.github.io/django-admin-data-views/)

**Source Code**: [https://github.com/MrThearMan/django-admin-data-views/](https://github.com/MrThearMan/django-admin-data-views/)

---

Django Admin Data Views enables you to easily add non-model data to the django admin panel.
Data from an API or file can be shown in similar table and item views than regular models.


![Example](https://github.com/MrThearMan/django-admin-data-views/raw/main/docs/img/example.png?raw=true)


[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/django-admin-data-views/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/workflow/status/MrThearMan/django-admin-data-views/Test
[pypi-badge]: https://img.shields.io/pypi/v/django-admin-data-views
[licence-badge]: https://img.shields.io/github/license/MrThearMan/django-admin-data-views
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/django-admin-data-views
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/django-admin-data-views
[version-badge]: https://img.shields.io/pypi/pyversions/django-admin-data-views
[downloads-badge]: https://img.shields.io/pypi/dm/django-admin-data-views
[django-badge]: https://img.shields.io/pypi/djversions/django-admin-data-views

[coverage]: https://coveralls.io/github/MrThearMan/django-admin-data-views?branch=main
[status]: https://github.com/MrThearMan/django-admin-data-views/actions/workflows/test.yml
[pypi]: https://pypi.org/project/django-admin-data-views
[licence]: https://github.com/MrThearMan/django-admin-data-views/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/django-admin-data-views/commits/main
[issues]: https://github.com/MrThearMan/django-admin-data-views/issues

==> django_admin_data_views-0.4.0.tar.gz: django_admin_data_views-0.4.0/README.md <==
# Django Admin Data Views

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Downloads][downloads-badge]][pypi]

[![Python Version][version-badge]][pypi]
[![Django Version][django-badge]][pypi]

```shell
pip install django-admin-data-views
```

---

**Documentation**: [https://mrthearman.github.io/django-admin-data-views/](https://mrthearman.github.io/django-admin-data-views/)

**Source Code**: [https://github.com/MrThearMan/django-admin-data-views/](https://github.com/MrThearMan/django-admin-data-views/)

**Contributing**: [https://github.com/MrThearMan/django-admin-data-views/blob/main/CONTRIBUTING.md](https://github.com/MrThearMan/django-admin-data-views/blob/main/CONTRIBUTING.md)

---

Django Admin Data Views enables you to easily add non-model data to the django admin panel.
Data from an API or file can be shown in similar table and item views than regular models.


![Example](https://github.com/MrThearMan/django-admin-data-views/raw/main/docs/img/example.png?raw=true)


[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/django-admin-data-views/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/actions/workflow/status/MrThearMan/django-admin-data-views/test.yml?branch=main
[pypi-badge]: https://img.shields.io/pypi/v/django-admin-data-views
[licence-badge]: https://img.shields.io/github/license/MrThearMan/django-admin-data-views
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/django-admin-data-views
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/django-admin-data-views
[version-badge]: https://img.shields.io/pypi/pyversions/django-admin-data-views
[downloads-badge]: https://img.shields.io/pypi/dm/django-admin-data-views
[django-badge]: https://img.shields.io/pypi/djversions/django-admin-data-views

[coverage]: https://coveralls.io/github/MrThearMan/django-admin-data-views?branch=main
[status]: https://github.com/MrThearMan/django-admin-data-views/actions/workflows/test.yml
[pypi]: https://pypi.org/project/django-admin-data-views
[licence]: https://github.com/MrThearMan/django-admin-data-views/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/django-admin-data-views/commits/main
[issues]: https://github.com/MrThearMan/django-admin-data-views/issues
